from setuptools import setup, find_packages
from setuptools.extension import Extension
from Cython.Build import cythonize


with open("README.rst") as f:
    LONG_DESCRIPTION = f.read()

setup(
    name="py-stringmatching",
    version="0.4.6",
    description="Python library for string matching.",
    long_description=LONG_DESCRIPTION,
    url="https://sites.google.com/site/anhaidgroup/projects/magellan/py_stringmatching",
    author="UW Magellan Team",
    author_email="uwmagellan@gmail.com",
    license="BSD",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Education",
        "License :: OSI Approved :: BSD License",
        "Operating System :: POSIX",
        "Operating System :: Unix",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Scientific/Engineering",
        "Topic :: Utilities",
        "Topic :: Software Development :: Libraries",
    ],
    packages=find_packages(exclude=["benchmarks"]),
    install_requires=["numpy"],
    setup_requires=["cython"],
    ext_modules=cythonize(
        Extension(
            "*",
            ["py_stringmatching/similarity_measure/cython/*.pyx"],
            define_macros=[("NPY_NO_DEPRECATED_API", "NPY_1_7_API_VERSION")],
        )
    ),
    include_package_data=False,
)
